summaryrefslogtreecommitdiffstats
path: root/noatun-plugins/ffrs/ffrs.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'noatun-plugins/ffrs/ffrs.cpp')
-rw-r--r--noatun-plugins/ffrs/ffrs.cpp42
1 files changed, 21 insertions, 21 deletions
diff --git a/noatun-plugins/ffrs/ffrs.cpp b/noatun-plugins/ffrs/ffrs.cpp
index 38fd56e..73f2685 100644
--- a/noatun-plugins/ffrs/ffrs.cpp
+++ b/noatun-plugins/ffrs/ffrs.cpp
@@ -22,7 +22,7 @@ extern "C" Plugin *create_plugin()
View::View(int width, int height, int block, int unblock, TQColor front, TQColor back, int channel)
- : TQWidget(0,0, Qt::WStyle_Customize | Qt::WStyle_NoBorder | Qt::WStyle_StaysOnTop | Qt::WType_TopLevel), mChannel(channel)
+ : TQWidget(0,0, TQt::WStyle_Customize | TQt::WStyle_NoBorder | TQt::WStyle_StaysOnTop | TQt::WType_TopLevel), mChannel(channel)
{
fg = front;
bg = back;
@@ -52,26 +52,26 @@ View::View(int width, int height, int block, int unblock, TQColor front, TQColor
// make sure we're on the desktop
if (
- !desktop.contains(rect().topLeft())
- || !desktop.contains(rect().bottomRight())
+ !desktop.tqcontains(rect().topLeft())
+ || !desktop.tqcontains(rect().bottomRight())
)
{
move(at);
}
- TQBitmap mask(width, height);
- TQPainter p(&mask);
+ TQBitmap tqmask(width, height);
+ TQPainter p(&tqmask);
-// Qt::color0 = transparent
-// Qt::color1 = opaque
- p.fillRect(0, 0, width, height, Qt::color0);
+// TQt::color0 = transparent
+// TQt::color1 = opaque
+ p.fillRect(0, 0, width, height, TQt::color0);
for (int i=0; i < height; )
{
- p.fillRect(0, height-i-block, width, block, Qt::color1);
+ p.fillRect(0, height-i-block, width, block, TQt::color1);
i += block + unblock;
}
- setMask(mask);
+ setMask(tqmask);
units = block+unblock;
show();
@@ -184,52 +184,52 @@ void FFRS::changed()
#include <tqhbox.h>
#include <tqlabel.h>
-FFRSPrefs::FFRSPrefs( TQObject *parent )
- : CModule(i18n("Foreign Region"), i18n("French Foreign Region"),"",parent)
+FFRSPrefs::FFRSPrefs( TQObject *tqparent )
+ : CModule(i18n("Foreign Region"), i18n("French Foreign Region"),"",tqparent)
{
- TQVBoxLayout *layout = new TQVBoxLayout(this);
+ TQVBoxLayout *tqlayout = new TQVBoxLayout(this);
TQHBox *box = new TQHBox(this);
- layout->addWidget(box);
+ tqlayout->addWidget(box);
new TQLabel(i18n("Width:"), box);
mWidth = new KIntNumInput(width(), box);
mWidth->setMinValue(0);
box = new TQHBox(this);
- layout->addWidget(box);
+ tqlayout->addWidget(box);
new TQLabel(i18n("Height:"), box);
mHeight = new KIntNumInput(height(), box);
mHeight->setMinValue(0);
box = new TQHBox(this);
- layout->addWidget(box);
+ tqlayout->addWidget(box);
new TQLabel(i18n("Visible block size:"), box);
mFgblock = new KIntNumInput(fgblock(), box);
mFgblock->setMinValue(0);
box = new TQHBox(this);
- layout->addWidget(box);
+ tqlayout->addWidget(box);
new TQLabel(i18n("Transparent block size:"), box);
mBgblock = new KIntNumInput(bgblock(), box);
mBgblock->setMinValue(0);
box = new TQHBox(this);
- layout->addWidget(box);
+ tqlayout->addWidget(box);
new TQLabel(i18n("Update interval:"), box);
mRate = new KIntNumInput(rate(), box);
mRate->setMinValue(0);
box = new TQHBox(this);
- layout->addWidget(box);
+ tqlayout->addWidget(box);
new TQLabel(i18n("Foreground color:"), box);
mFgcolor = new KColorButton(fgcolor(), box);
box = new TQHBox(this);
- layout->addWidget(box);
+ tqlayout->addWidget(box);
new TQLabel(i18n("Background color:"), box);
mBgcolor = new KColorButton(bgcolor(), box);
- layout->addStretch();
+ tqlayout->addStretch();
}
void FFRSPrefs::save()